@@ -18,7 +18,7 @@
 #'     evidence-functions in the future.
 #' 
 #' @name finding
-#' 
+#' @concept old_names
 #' @aliases setFinding retractFinding getFinding pFinding
 #' @param object A "grain" object
 #' @param nodes A vector of nodes
@@ -50,18 +50,19 @@
 #' \url{https://www.jstatsoft.org/v46/i10/}.
 #'
 #' @keywords models utilities
+#'
 #' @examples
 #' 
 #' ## setFindings
 #' yn <- c("yes", "no")
-#' a    <- cptable(~asia, values=c(1, 99),levels=yn)
-#' t.a  <- cptable(~tub+asia, values=c(5, 95, 1, 99),levels=yn)
-#' s    <- cptable(~smoke, values=c(5,5), levels=yn)
-#' l.s  <- cptable(~lung+smoke, values=c(1, 9, 1, 99), levels=yn)
-#' b.s  <- cptable(~bronc+smoke, values=c(6, 4, 3, 7), levels=yn)
-#' e.lt <- cptable(~either+lung+tub,values=c(1, 0, 1, 0, 1, 0, 0, 1),levels=yn)
-#' x.e  <- cptable(~xray+either, values=c(98, 2, 5, 95), levels=yn)
-#' d.be <- cptable(~dysp+bronc+either, values=c(9, 1, 7, 3, 8, 2, 1, 9), levels=yn)
+#' a    <- cpt(~asia, values=c(1, 99),levels=yn)
+#' t.a  <- cpt(~tub+asia, values=c(5, 95, 1, 99),levels=yn)
+#' s    <- cpt(~smoke, values=c(5,5), levels=yn)
+#' l.s  <- cpt(~lung+smoke, values=c(1, 9, 1, 99), levels=yn)
+#' b.s  <- cpt(~bronc+smoke, values=c(6, 4, 3, 7), levels=yn)
+#' e.lt <- cpt(~either+lung+tub,values=c(1, 0, 1, 0, 1, 0, 0, 1),levels=yn)
+#' x.e  <- cpt(~xray+either, values=c(98, 2, 5, 95), levels=yn)
+#' d.be <- cpt(~dysp+bronc+either, values=c(9, 1, 7, 3, 8, 2, 1, 9), levels=yn)
 #' chest.cpt <- compileCPT(a, t.a, s, l.s, b.s, e.lt, x.e, d.be)
 #' chest.bn <- grain(chest.cpt)
 #' 
@@ -92,7 +93,10 @@ setFinding <- function(object, nodes=NULL, states=NULL, flist=NULL, propagate=TR
         nodes   <- flist2[,1]
         states  <- flist2[,2]
     }
-    setEvidence(object, nodes=nodes, states=states, propagate=propagate)
+    ## setEvidence(object, nodes=nodes, states=states, propagate=propagate)
+    evi <- setNames(as.list(states), nodes)
+    setEvidence(object, evidence=evi)
+
 }
 
 #' @export 
